@@ -29,6 +29,7 @@ namespace pl::gen::fmt {
         void visit(pl::ptrn::PatternWideCharacter& pattern) override { formatString(&pattern);      }
         void visit(pl::ptrn::PatternWideString& pattern)    override { formatString(&pattern);      }
         void visit(pl::ptrn::Pattern& pattern)              override { formatString(&pattern);      }
+        void visit(pl::ptrn::PatternError& pattern)         override { formatString(&pattern);      }
 
         [[nodiscard]] auto getResult() const {
             return this->m_result;
@@ -61,7 +62,7 @@ namespace pl::gen::fmt {
 
             addLine(pattern->getVariableName());
             pushIndent();
-            pattern->forEachEntry(0, pattern->getEntryCount(), [&](u64, auto member) {
+            pattern->forEachEntry(0, pattern->getEntryCount(), [&](u64, const auto &member) {
                 this->m_inArray = true;
                 member->accept(*this);
             });
@@ -92,14 +93,14 @@ namespace pl::gen::fmt {
                 for (const auto &[name, value] : this->getMetaInformation(pattern))
                     addLine(name, ::fmt::format("\"{}\"", value));
 
-                pattern->forEachEntry(0, pattern->getEntryCount(), [&](u64, auto member) {
+                pattern->forEachEntry(0, pattern->getEntryCount(), [&](u64, const auto &member) {
                     member->accept(*this);
                 });
                 popIndent();
             }
         }
 
-        void formatString(const pl::ptrn::Pattern *pattern) {
+        void formatString(pl::ptrn::Pattern *pattern) {
             if (pattern->getVisibility() == ptrn::Visibility::Hidden) return;
             if (pattern->getVisibility() == ptrn::Visibility::TreeHidden) return;
 
@@ -109,7 +110,7 @@ namespace pl::gen::fmt {
             addLine(pattern->getVariableName(), ::fmt::format("\"{}\"", hlp::encodeByteString({ result.begin(), result.end() })));
         }
 
-        void formatValue(const pl::ptrn::Pattern *pattern) {
+        void formatValue(pl::ptrn::Pattern *pattern) {
             if (pattern->getVisibility() == ptrn::Visibility::Hidden) return;
             if (pattern->getVisibility() == ptrn::Visibility::TreeHidden) return;
 
