@@ -2,8 +2,7 @@
 
 #include <pl/patterns/pattern.hpp>
 
-#include <codecvt>
-#include <locale>
+#include <wolv/utils/string.hpp>
 
 namespace pl::ptrn {
 
@@ -12,12 +11,12 @@ namespace pl::ptrn {
         explicit PatternWideCharacter(core::Evaluator *evaluator, u64 offset, u32 line)
             : Pattern(evaluator, offset, 2, line) { }
 
-        [[nodiscard]] std::unique_ptr<Pattern> clone() const override {
+        [[nodiscard]] std::shared_ptr<Pattern> clone() const override {
             return std::unique_ptr<Pattern>(new PatternWideCharacter(*this));
         }
 
         [[nodiscard]] core::Token::Literal getValue() const override {
-            char16_t character = '\u0000';
+            char16_t character = u'\u0000';
             this->getEvaluator()->readData(this->getOffset(), &character, 2, this->getSection());
             return transformValue(u128(hlp::changeEndianess(character, this->getEndian())));
         }
@@ -26,12 +25,12 @@ namespace pl::ptrn {
             return "char16";
         }
 
-        [[nodiscard]] std::string toString() const override {
+        [[nodiscard]] std::string toString() override {
             auto value = this->getValue();
-            char16_t character = value.toUnsigned();
+            char16_t character = char16_t(value.toUnsigned());
             character = hlp::changeEndianess(character, this->getEndian());
 
-            auto result = std::wstring_convert<std::codecvt_utf8_utf16<char16_t>, char16_t>("???").to_bytes(character);
+            auto result = wolv::util::utf16ToUtf8(std::u16string(&character, 1)).value_or("???");
 
             return Pattern::callUserFormatFunc(value, true).value_or(result);
         }
@@ -58,4 +57,4 @@ namespace pl::ptrn {
         }
     };
 
-}
\ No newline at end of file
+}
