@@ -17,6 +17,11 @@ namespace pl::core::resolvers {
             bool exists = false;
             // if the path has no extension
             if (!fullPath.has_extension()) {
+                // If the path points to a directory, check for a file called "pattern" inside of it
+                if (std::fs::is_directory(fullPath)) {
+                    fullPath /= "pattern";
+                }
+
                 for (const auto &ext : { "hexpat", "pat" }) {
                     fullPath.replace_extension(ext);
                     exists = std::fs::exists(fullPath);
@@ -42,9 +47,10 @@ namespace pl::core::resolvers {
                 return Result::err("Path " + utf8 + " is not a regular file");
             }
 
-            const auto content = file.readString();
+            auto content = file.readString();
+            content = wolv::util::replaceStrings(content, "\r\n", "\n");
 
-            return Result::good(api::Source { content, utf8 });
+            return Result::good(api::Source(content, utf8, false));
         }
 
         return Result::err("Could not find file " + path);
