@@ -15,6 +15,7 @@
 
 #include <fmt/args.h>
 
+
 using namespace pl;
 using namespace pl::test;
 
@@ -38,7 +39,7 @@ int runTests(int argc, char **argv) {
     bool failing         = currTest->getMode() == Mode::Failing;
 
     wolv::io::File testData("test_data", wolv::io::File::Mode::Read);
-    static pl::PatternLanguage runtime;
+    pl::PatternLanguage runtime;
     runtime.setDataSource(0x00, testData.getSize(), [&testData](u64 offset, u8 *buffer, u64 size) {
         testData.seek(offset);
         testData.readBuffer(buffer, size);
@@ -107,20 +108,23 @@ int runTests(int argc, char **argv) {
     auto &test = testPatterns[testName];
     test->m_runtime = &runtime;
     test->setup();
-    auto result = runtime.executeString(test->getSourceCode(), "<test: " + testName + ">");
 
-    // Check if compilation succeeded
-    if (!result) {
-        fmt::print("Error during test!\n");
+    for (size_t i = 0; i < test->repeatTimes(); i++) {
+        auto result = runtime.executeString(test->getSourceCode());
 
-        if (auto error = runtime.getEvalError(); error.has_value())
-            fmt::print("Error: {}:{} : {}\n", error->line, error->column, error->message);
+        // Check if compilation succeeded
+        if (!result) {
+            fmt::print("Error during test!\n");
 
-        for (const auto& error : runtime.getCompileErrors()) {
-            fmt::print("{}", error.format());
+            if (auto error = runtime.getEvalError(); error.has_value())
+                fmt::print("Error: {}:{} : {}\n", error->line, error->column, error->message);
+
+            for (const auto& error : runtime.getCompileErrors()) {
+                fmt::print("{}", error.format());
+            }
+
+            return failing ? EXIT_SUCCESS : EXIT_FAILURE;
         }
-
-        return failing ? EXIT_SUCCESS : EXIT_FAILURE;
     }
 
     const auto &evaluatedPatterns = runtime.getPatterns();
